@@ -1,7 +1,6 @@
 import pytest
 
 from ..utils import with_peers
-from .conftest import data_test, data_large
 
 
 @pytest.fixture
@@ -10,15 +9,16 @@ def peers():
     return [{}, {}]
 
 
-def test_send(peers):
-    """Tests data sending from one peer to another"""
-    connection = peers[0].connect(peers[1].address_name, data_type="json")
-
-    connection.send(data_test)
-
-
 def test_send_large(peers):
     """Tests relatively large data sending from one peer to another"""
     connection = peers[0].connect(peers[1].address_name, data_type="raw")
 
-    connection.send(data_large)
+    connection.send(list(range(int(2e6))))
+
+
+def test_stream(peers):
+    """Tests relatively large data sending from one peer to another"""
+    connection = peers[0].connect(peers[1].address_name, data_type="raw", stream=True)
+
+    for _ in range(10):
+        connection.send("2easy4u")
